@@ -195,7 +195,10 @@ int disconnect_kex_failed(struct ssh_connection *connection, const char *msg)
 }
 
 #if DATAFELLOWS_SSH2_SSH_DSA_KLUDGE
-static int invoke_ssh2_dsa_kludge_p(struct lsh_string *s)
+/* FIXME: A more general handling of workarounds and version numbers 
+ * would be needed */
+
+int invoke_ssh2_dsa_kludge_p(struct lsh_string *s)
 {
   /* FIXME: Improve the version string test. */
   return( (s->length >= 15)
